cmoncrawl.processor.pipeline.router.Route — CmonCrawl 1.0.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# cmoncrawl.processor.pipeline.router.Route

class cmoncrawl.processor.pipeline.router.Route(name: str, regexes: List[re.Pattern[str]], since: datetime.datetime, to: datetime.datetime)
  __init__(name: str, regexes: List[Pattern[str]], since: datetime, to: datetime) → None

  Methods

  `__init__`(name, regexes, since, to) |

  Attributes

  `name` |
  `regexes` |
  `since` |
  `to` |